@@ -139,10 +139,12 @@ class MediaShowListingView(BrowserView):
         plone_utils = getToolByName(self.context, 'plone_utils')
         path = '/'.join(item.getPhysicalPath())
         
-        if item.portal_type == "Folder" or (item.restrictedTraverse('@@plone').isStructuralFolder()  and item.portal_type != "Topic"):
+        if item.portal_type == "Folder" or (item.restrictedTraverse('@@plone').isStructuralFolder()  and item.portal_type != "Topic" and item.portal_type != "Category Navigator"):
             results = catalog.searchResults(path = { 'query' : path, 'depth' : 1 }, sort_on = 'getObjPositionInParent')
         elif item.portal_type == "Topic":
-            results = catalog.searchResults(item.getQuery())
+            results = catalog.searchResults(item.buildQuery())
+        elif item.portal_type == "Category Navigator" and hasattr(self.request, 'Subject'):
+            results = catalog.searchResults(Subject = self.request['Subject'])
         else:
             results = []
          
